@@ -2,7 +2,7 @@
 
 # Laurent Montel <montel@kde.org> (2014)
 # KIcon("...") => QIcon::fromTheme("...")
-# find -iname "*.cpp"|xargs kde-dev-scripts/kf5/convert-kicon.pl
+# find -iname "*.cpp" -o -iname "*.h"|xargs kde-dev-scripts/kf5/convert-kicon.pl
 
 use strict;
 use File::Basename;
@@ -15,8 +15,12 @@ foreach my $file (@ARGV) {
     open(my $FILE, "<", $file) or warn "We can't open file $file:$!\n";
     my @l = map {
         my $orig = $_;
-        s/\bKIcon\b\s*\(/QIcon::fromTheme(/;
+        if (/KIcon\(\s*\)/ ) {
+           s/KIcon\(\s*\)/QIcon()/;
+        }
+        s/\bKIcon\b\s*\(/QIcon::fromTheme(/g;
         s/\<KIcon\b\>/\<QIcon>/ =~ /#include/ ;
+        s/\<kicon.h\b\>/\<QIcon>/ =~ /#include/ ;
 
         $modified ||= $orig ne $_;
         $_;
